@@ -6,8 +6,11 @@ from pathlib import Path
 import httpx
 
 from .common import (
-    DEFAULT_CONFIG_FILENAME, body_to_bytes, load_yaml, set_access_token,
+    DEFAULT_CONFIG_FILENAME,
+    body_to_bytes,
+    load_yaml,
     patch_response,
+    set_access_token,
 )
 
 logger = logging.getLogger(__name__)
@@ -19,13 +22,13 @@ def load_app(import_path, django_settings_module=None):
     os.environ["DJANGO_SETTINGS_MODULE"] = django_settings_module or ""
     *submodules, app_name = import_path.split(".")
     module = import_module(".".join(submodules))
-    app = getattr(module, app_name)
-    return app
+    application = getattr(module, app_name)
+    return application
 
 
-def call_app(app, event):
+def call_app(application, event):
     """
-    call wsgi app
+    call wsgi application
     see https://cloud.yandex.ru/docs/functions/concepts/function-invoke
     #response
     """
@@ -34,26 +37,27 @@ def call_app(app, event):
         host_url = f"https://{host_url}"
     body_to_bytes(event)
 
-    with httpx.Client(app=app,
-                      base_url=host_url) as client:
+    with httpx.Client(app=application, base_url=host_url) as client:
         request = client.build_request(
             method=event["httpMethod"],
             url=event["url"],
             headers=event["headers"],
             params=event["queryStringParameters"],
             content=event["body"],
-            )
+        )
         response = client.send(request)
         return response
 
 
 try:
     set_access_token()
-    config = load_yaml(Path(Path(__file__).resolve().parent.parent,
-                            DEFAULT_CONFIG_FILENAME))
+    config = load_yaml(
+        Path(Path(__file__).resolve().parent.parent, DEFAULT_CONFIG_FILENAME)
+    )
 
-    app = load_app(config.get("entrypoint"),
-                   config.get("django_settings_module"))
+    app = load_app(
+        config.get("entrypoint"), config.get("django_settings_module")
+    )
 except ValueError:
     logger.warning("Couldn't load app. Looks like broken Yappa config is used")
 
@@ -62,9 +66,9 @@ def handle(event, context):
     set_access_token()
     if not event:
         return {
-            'statusCode': 500,
-            'body': "got empty event",
-            }
+            "statusCode": 500,
+            "body": "got empty event",
+        }
     try:
         response = call_app(app, event)
         return patch_response(response)
@@ -73,5 +77,5 @@ def handle(event, context):
         return {
             "statusCode": 500,
             "body": f"got unhandled exception ({e}). Most likely on "
-                    f"Yappa side. See clouds logs for traceback"
-            }
+            f"Yappa side. See clouds logs for traceback",
+        }
