@@ -4,15 +4,16 @@ from typing import Iterable
 
 from google.protobuf.empty_pb2 import Empty
 from yandex.cloud.serverless.apigateway.v1.apigateway_pb2 import ApiGateway
-from yandex.cloud.serverless.apigateway.v1.apigateway_service_pb2 import \
-    (
-    CreateApiGatewayMetadata, CreateApiGatewayRequest,
+from yandex.cloud.serverless.apigateway.v1.apigateway_service_pb2 import (
+    CreateApiGatewayMetadata,
+    CreateApiGatewayRequest,
     DeleteApiGatewayMetadata,
     DeleteApiGatewayRequest,
     ListApiGatewayRequest,
 )
-from yandex.cloud.serverless.apigateway.v1.apigateway_service_pb2_grpc import \
-    ApiGatewayServiceStub
+from yandex.cloud.serverless.apigateway.v1.apigateway_service_pb2_grpc import (
+    ApiGatewayServiceStub,
+)
 
 logger = logging.getLogger(__name__)
 
@@ -29,18 +30,23 @@ class YcGatewayMixin:
         for gw in gateways:
             if gw.name == name:
                 return gw
-        raise ValueError("Oops. Didn't find any gateway by name "
-                         f"{name}, saw only "
-                         f"{','.join([gw.name for gw in gateways])}")
+        raise ValueError(
+            "Oops. Didn't find any gateway by name "
+            f"{name}, saw only "
+            f"{','.join([gw.name for gw in gateways])}"
+        )
 
     def _get_gateways(self, filter_=None) -> Iterable[ApiGateway]:
-        gateways = self.sdk.client(ApiGatewayServiceStub).List(
-            ListApiGatewayRequest(folder_id=self.folder_id,
-                                  filter=filter_)).api_gateways
+        gateways = (
+            self.sdk.client(ApiGatewayServiceStub)
+            .List(
+                ListApiGatewayRequest(folder_id=self.folder_id, filter=filter_)
+            )
+            .api_gateways
+        )
         return gateways
 
-    def create_gateway(self, name, openapi_spec,
-                       description="") -> ApiGateway:
+    def create_gateway(self, name, openapi_spec, description="") -> ApiGateway:
         with suppress(ValueError):
             gateway = self.get_gateway(name)
             return gateway, False
@@ -49,8 +55,9 @@ class YcGatewayMixin:
                 folder_id=self.folder_id,
                 name=name,
                 description=description,
-                openapi_spec=openapi_spec
-            ))
+                openapi_spec=openapi_spec,
+            )
+        )
         operation_result = self.sdk.wait_operation_and_get_result(
             operation,
             response_type=ApiGateway,
@@ -63,16 +70,18 @@ class YcGatewayMixin:
         operation = self.sdk.client(ApiGatewayServiceStub).Delete(
             DeleteApiGatewayRequest(
                 api_gateway_id=gateway.id,
-            ))
+            )
+        )
         self.sdk.wait_operation_and_get_result(
             operation,
             response_type=Empty,
             meta_type=DeleteApiGatewayMetadata,
         )
 
-    def update_gateway(self, gateway_name, description,
-                       openapi_spec) -> ApiGateway:
+    def update_gateway(
+        self, gateway_name, description, openapi_spec
+    ) -> ApiGateway:
         logger.warning("Update gateway is not yet implemented")
         gateway = self.get_gateway(gateway_name)
-        # TODO imlement update
+        # TODO implement update
         return gateway
